@@ -16,12 +16,6 @@ logger = logging.getLogger(__name__)
 class AdminChartsView(TemplateView):
     template_name = 'admin_tools_stats/admin_charts.js'
 
-    def get_context_data(self, *args, interval=None, graph_key=None, **kwargs):
-        context = super().get_context_data(*args, **kwargs)
-        context['chart_height'] = 300
-        context['chart_width'] = '100%'
-        return context
-
 
 interval_dateformat_map = {
     'years': ("%Y", "%Y"),
@@ -103,3 +97,12 @@ class ChartDataView(TemplateView):
 
         context['chart_container'] = "chart_container_" + graph_key
         return context
+
+
+class AnalyticsView(TemplateView):
+    template_name = 'admin_tools_stats/analytics.html'
+
+    def get_context_data(self, *args, **kwargs):
+        context_data = super().get_context_data(*args, **kwargs)
+        context_data['charts'] = DashboardStats.objects.all()
+        return context_data
